@@ -2,7 +2,7 @@
  * SCIM-chewing -
  *	Intelligent Chinese Phonetic IM Engine for SCIM.
  *
- * Copyright (c) 2004, 2005
+ * Copyright (c) 2004, 2005, 2006
  *	SCIM-chewing Developers. See ChangeLog for details.
  *
  * See the file "COPYING" for information on usage and redistribution
@@ -23,12 +23,11 @@ class ChewingLookupTable : public LookupTable
 		virtual AttributeList get_attributes ( int index ) const;
 		virtual unsigned int number_of_candidates() const;
 		virtual void clear();
-		void init();
+		void init( String s, int num );
 		void update( ChoiceInfo *ci );
 	private:
 		ChoiceInfo *pci;
 		int current_page;
-		IConvert m_iconv;
 };
 
 class ChewingIMEngineFactory : public IMEngineFactoryBase
@@ -59,9 +58,15 @@ private:
 	Connection m_reload_signal_connection;
 
 	KeyEventList m_chi_eng_keys;
-	String m_default_KeyboardType;
+	String m_KeyboardType;
+	String m_selection_keys;
+	int m_selection_keys_num;
 	bool m_add_phrase_forward;
 	bool m_space_as_selection;
+	bool m_esc_clean_all_buffer;
+
+	/* A series of background colors used in preedit area */
+	unsigned int m_preedit_bgcolor[5];
 
 	friend class ChewingIMEngineInstance;
 };
@@ -93,6 +98,7 @@ private:
 	void initialize_all_properties ();
 	void refresh_all_properties ();
 	void refresh_chieng_property ();
+	void refresh_letter_property ();
 
 	Connection m_reload_signal_connection;
 	WideString m_converted_string;
@@ -102,11 +108,9 @@ private:
 	KeyEvent m_prev_key;
 	ChewingIMEngineFactory *m_factory;
 	ChewingLookupTable m_lookup_table;
-	IConvert m_iconv;
-	ChewingConf cf;
-	ChewingData da;
-	ConfigData config;
-	ChewingOutput gOut;
+	ChewingContext *ctx;
+	ChewingConfigData config;
+    bool have_input;
 };
 
 #endif
